==> spring-cloud-netflix-sidecar-1.3.2.RELEASE-sources.jar: org/springframework/cloud/netflix/sidecar/SidecarController.java <==
/*
 * Copyright 2013-2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.cloud.netflix.sidecar;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.cloud.client.ServiceInstance;
import org.springframework.cloud.client.discovery.DiscoveryClient;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author Spencer Gibb
 */
@RestController
public class SidecarController {

	@Autowired
	private DiscoveryClient discovery;

	@Value("${spring.application.name}")
	private String appName;

	@RequestMapping("/ping")
	public String ping() {
		return "OK";
	}

	@RequestMapping("/hosts/{appName}")
	public List<ServiceInstance> hosts(@PathVariable("appName") String appName) {
		return hosts2(appName);
	}

	@RequestMapping("/hosts")
	public List<ServiceInstance> hosts2(@RequestParam("appName") String appName) {
		List<ServiceInstance> instances = this.discovery.getInstances(appName);
		return instances;
	}

	@RequestMapping(value = "/", produces = "text/html")
	public String home() {
		return "<head><title>Sidecar</title></head><body>\n"
				+ "<a href='/ping'>ping</a><br/>\n"
				+ "<a href='/health'>health</a><br/>\n" + "<a href='/hosts/"
				+ this.appName + "'>hosts/" + this.appName + "</a><br/>\n" + "</body>";
	}

}

==> spring-cloud-netflix-sidecar-2.2.9.RELEASE-sources.jar: org/springframework/cloud/netflix/sidecar/SidecarController.java <==
/*
 * Copyright 2013-2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.cloud.netflix.sidecar;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.cloud.client.ServiceInstance;
import org.springframework.cloud.client.discovery.DiscoveryClient;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author Spencer Gibb
 */
@RestController
public class SidecarController {

	@Autowired
	private DiscoveryClient discovery;

	@Value("${spring.application.name}")
	private String appName;

	@RequestMapping("/ping")
	public String ping() {
		return "OK";
	}

	@RequestMapping("/hosts/{appName}")
	public List<ServiceInstance> hosts(@PathVariable("appName") String appName) {
		return hosts2(appName);
	}

	@RequestMapping("/hosts")
	public List<ServiceInstance> hosts2(@RequestParam("appName") String appName) {
		List<ServiceInstance> instances = this.discovery.getInstances(appName);
		return instances;
	}

	@RequestMapping(value = "/", produces = "text/html")
	public String home() {
		return "<head><title>Sidecar</title></head><body>\n"
				+ "<a href='/ping'>ping</a><br/>\n"
				+ "<a href='/actuator/health'>health</a><br/>\n" + "<a href='/hosts/"
				+ this.appName + "'>hosts/" + this.appName + "</a><br/>\n" + "</body>";
	}

}
